"""
.. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
"""

import platform
from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Union, cast

import pkg_resources

from .__version__ import __author__, __copyright__, __email__, __license__, __version__


def get_envinfo(packages: Optional[Sequence[str]] = None) -> Dict[str, str]:
    uname = platform.uname()
    envinfo = {
        "uname": "{} {} {} {}".format(uname.system, uname.node, uname.release, uname.machine),
        "implementation": platform.python_implementation(),
        "version": platform.python_version(),
    }

    if not packages:
        return envinfo

    for pkg in packages:
        if not pkg:
            continue

        key = "{} version".format(pkg)
        try:
            envinfo[key] = pkg_resources.get_distribution(pkg).version
        except pkg_resources.DistributionNotFound:
            envinfo[key] = "not installed"

    return envinfo


def dumps(packages: Optional[Sequence[str]] = None, format: Optional[str] = None) -> str:
    envinfo = get_envinfo(packages)
    uname = envinfo.pop("uname")
    implementation = envinfo.pop("implementation")
    version = envinfo.pop("version")

    lines = ["uname: {}".format(uname), "{} version: {}".format(implementation, version)]
    lines.extend(["{}: {}".format(key, value) for key, value in envinfo.items()])

    if format and format.strip().lower() == "markdown":
        lines = ["- {}".format(line) for line in lines]

    return "\n".join(lines)



import re

import envinfopy


RE_VERSION = re.compile(r"[0-9]\.[0-9]+\.[0-9]+", re.MULTILINE)


class Test_get_envinfo:
    def test_normal(self):
        envinfo = envinfopy.get_envinfo(["pytest", "envinfopy"])
        print(envinfo)

        assert len(envinfo["uname"]) >= 10
        assert RE_VERSION.search(envinfo["version"])
        assert RE_VERSION.search(envinfo["pytest version"])
        assert RE_VERSION.search(envinfo["envinfopy version"])

    def test_abnormal_not_installed(self):
        envinfo = envinfopy.get_envinfo(["not-installed-pkg"])
        print(envinfo)

        assert len(envinfo["uname"]) >= 10
        assert RE_VERSION.search(envinfo["version"])
        assert envinfo["not-installed-pkg version"] == "not installed"

    def test_abnormal_empty(self):
        envinfo = envinfopy.get_envinfo([""])

        assert envinfo == envinfopy.get_envinfo()


class Test_dumps:
    def test_smoke(self):
        output = envinfopy.dumps()

        assert len(output) > 20
        assert RE_VERSION.search(output)



#!/usr/bin/env python3

"""
.. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
"""

import argparse
from textwrap import dedent

from . import dumps
from .__version__ import __version__


def parse_option() -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter,
        epilog=dedent(
            """\
            Issue tracker: https://github.com/thombashi/envinfopy/issues
            """
        ),
    )
    parser.add_argument(
        "-V", "--version", action="version", version="%(prog)s {}".format(__version__)
    )

    parser.add_argument(
        "--packages",
        default="",
        help="comma-separated packages that extract versions.",
    )
    parser.add_argument(
        "--format",
        choices=["text", "markdown"],
        default="text",
        help="output format",
    )

    return parser.parse_args()


def main() -> None:
    options = parse_option()

    print(dumps(options.packages.split(","), options.format))


if __name__ == "__main__":
    main()



import re
import sys

from subprocrunner import SubprocessRunner


RE_VERSION = re.compile(r"[0-9]\.[0-9]+\.[0-9]+", re.MULTILINE)


class Test_cli:
    def test_help(self, tmpdir):
        runner = SubprocessRunner([sys.executable, "-m", "envinfopy", "-h"])
        runner.run()
        assert runner.returncode == 0

    def test_smoke(self, tmpdir):
        runner = SubprocessRunner([sys.executable, "-m", "envinfopy", "--packages", "envinfopy"])
        runner.run()

        print(runner.stdout)

        assert runner.returncode == 0
        assert RE_VERSION.search(runner.stdout)
        assert re.search("envinfopy version:", runner.stdout, re.MULTILINE)
